import {
  PackageConfig,
  defaultAuditThresholds,
  playAudit,
} from '@genesislcap/foundation-testing/e2e';
import type { Locator, Page } from '@playwright/test';

export class HeaderPage {
  config: PackageConfig;
  port: number;
  page: Page;
  navBar: Locator;
  hamburgerMenu: Locator;
  navBarLogo: Locator;
  routeButtons: Locator;
  sideNav: Locator;
  sideNavLogo: Locator;
  logoutButton: Locator;
  connectionIndicator: Locator;
  userButton: Locator;

  constructor(config: PackageConfig, port: number, page: Page) {
    this.config = config;
    this.port = port;
    this.page = page;
    /**
     * Locate fields not guarded by conditionals upfront, and the remaining on-demand
     */
    // Define the locators
    this.navBar = this.page.locator('.nav-listbox[data-test-id="nav-bar"]');
    this.hamburgerMenu = this.navBar.locator('.bars-container[data-test-id="hamburger-menu"]');
    this.navBarLogo = this.navBar.locator('.logo-container[data-test-id="nav-bar-logo"]');
    this.routeButtons = this.navBar.locator('slot[name="routes"][data-test-id="route-buttons"]');

    // Side navigation locators
    this.sideNav = this.page.locator('zero-flyout[data-test-id="side-nav"]');
    this.sideNavLogo = this.sideNav.locator('img[data-test-id="side-nav-logo"]');
    this.logoutButton = this.sideNav.locator('.logout-container[data-test-id="logout-button"]');

    // Other locators
    this.connectionIndicator = this.navBar.locator(
      '.connection-indicator-container[data-test-id="connection-indicator"]'
    );
    this.userButton = this.navBar.locator('zero-button[data-test-id="user-button"]');
  }

  async goto() {
    await this.page.goto('/');
  }

  async audit() {
    await playAudit({
      page: this.page,
      port: this.port,
      thresholds: defaultAuditThresholds, // TODO: this should be coming from foundation-testing/src/playwright/test.ts base config
    });
  }
}
